@@ -30,6 +30,7 @@ function(x)
     if(!relation_is_crisp(x))
         stop("Argument 'x' must be a crisp relation.")
     I <- relation_incidence(x)
+    diag_hold <- diag(I)
     diag(I) <- 0
     has_children <- rowSums(I) > 0
     for (i in which(has_children)) {
@@ -43,6 +44,7 @@ function(x)
     }
     meta <- list(is_endorelation = TRUE,
                  is_transitive = TRUE)
+    diag(I) <- diag_hold
     .make_relation_from_domain_and_incidence(.domain(x), I, meta)
 }
 
@@ -55,11 +57,13 @@ function(x)
     if(!(is.relation(x) && relation_is_endorelation(x)))
         stop("Argument 'x' must be an endorelation.")
     I <- relation_incidence(x)
+    diag_hold <- diag(I)
     diag(I) <- 1
     for (i in seq_len(ncol(I)))
-        I <- .S.(I, outer(I[,i], I[i,], ".T."))
+        I <- .S.(I, outer(I[,i], I[i,], .T.))
     meta <- list(is_endorelation = TRUE,
                  is_transitive = TRUE)
+    diag(I) <- diag_hold
     .make_relation_from_domain_and_incidence(.domain(x), I, meta)
 }
 
@@ -95,39 +99,29 @@ function(x)
     .make_relation_from_domain_and_incidence(.domain(x), I, meta)
 }
 
-### * relation_left_trace
+### * relation_trace
 
-relation_left_trace <-
-function(x)
+relation_trace <-
+function(x, which)
 {
     if(!(is.relation(x) && relation_is_endorelation(x)))
         stop("Argument 'x' must be an endorelation.")
+    which <- match.arg(which, c("left", "right"))
     D <- .domain(x)
     x <- relation_incidence(x)
     n <- nrow(x)
     I <- matrix(1, nrow = n, ncol = n)
-    for(k in seq_len(n))
-        I <- pmin(I, outer(x[k, ], x[k, ], .I.))
-    .make_relation_from_domain_and_incidence(D, I)
+    if(which == "left") {
+        for(k in seq_len(n))
+            I <- pmin(I, outer(x[k, ], x[k, ], .I.))
+        .make_relation_from_domain_and_incidence(D, I)
+    } else {
+        for(k in seq_len(n))
+            I <- pmin(I, outer(x[, k], x[, k], .I.))
+        .make_relation_from_domain_and_incidence(D, t(I))
+    }
 }
 
-### * relation_right_trace
-
-relation_right_trace <-
-function(x)
-{
-    if(!(is.relation(x) && relation_is_endorelation(x)))
-        stop("Argument 'x' must be an endorelation.")
-    D <- .domain(x)
-    x <- relation_incidence(x)
-    n <- nrow(x)
-    I <- matrix(1, nrow = n, ncol = n)
-    for(k in seq_len(n))
-        I <- pmin(I, outer(x[, k], x[, k], .I.))
-    .make_relation_from_domain_and_incidence(D, t(I))
-}
-
-
 ### Local variables: ***
 ### mode: outline-minor ***
 ### outline-regexp: "### [*]+" ***
